pub struct Options {
pub width: u32,
pub height: u32,
pub rect: Rect,
pub page: u32,
pub format: ImageFormat,
}Fields
width: u32The destination width of the rendered page. If width is not specified, the page’s aspect ratio is maintained relative to the destination height.
height: u32The destination height of the rendered page. If height is not specified, the page’s aspect ratio is maintained relative to the destination width.
rect: RectThe portion of the PDF page to be rendered. If rect is not specified, the whole page is rendered.
page: u32The page index to be rendered. If page is not specified, the first page is rendered.
format: ImageFormatThe image format of thumbnail. If format is not specified, PNG format is used.